@@ -18,38 +18,33 @@
 //
 //
 
-using Gtk;
 using System;
+using Gtk;
 
 namespace lat 
 {
 	public class AboutDialog
 	{
-		private static string[] _author = { "Loren Bandiera" };
-		private static string[] _docs = { "Loren Bandiera" };
-		private static string _translators = "Pablo Borges (pt_BR)\nThomas Constans (fr_FR)";
-		private static string _desc = "LDAP Administration Tool";
-		private static string _copy = "Copyright 2005 MMG Security Inc.";
+		static string[] _author = { "Loren Bandiera" };
+		static string[] _docs = { "Loren Bandiera" };
+		static string _translators = "Pablo Borges (pt_BR)\nThomas Constans (fr_FR)";
+		static string _desc = "LDAP Administration Tool";
+		static string _copy = "Copyright \xa9 2005-2006 MMG Security Inc.";
 
 		public AboutDialog ()
 		{
-			Gnome.About ab = new Gnome.About (
-				Defines.PACKAGE,
-				Defines.VERSION,
-				_copy,
-				_desc,
-				_author,
-				_docs, 
-				_translators, 
-				null);
-
+			Gtk.AboutDialog ab = new Gtk.AboutDialog ();
+			ab.Authors = _author;
+			ab.Comments = _desc;
+			ab.Copyright = _copy;
+			ab.Documenters = _docs;
+			ab.Name = Defines.PACKAGE;
+			ab.TranslatorCredits = _translators;
+			ab.Version = Defines.VERSION;
 			ab.Icon = Global.latIcon;
-			ab.Show ();
-		}
 
-		public static void Show ()
-		{
-			new AboutDialog ();
+			ab.Run ();
+			ab.Destroy ();
 		}
 	}
 }
